========
Assembly
========

Features in Abaqus/CAE include Parts, Datums, Partitions, and Assembly operations. Assembly commands create Feature objects on only the rootAssembly object. The commands that create Feature objects on only the Part object are described in Part commands. The commands that create Feature objects on both the Part and the rootAssembly objects are described in Feature commands.

Create instances
----------------

.. autoclass:: abaqus.Assembly.AssemblyModel.AssemblyModel
    :noindex:

    .. autoclasstoc::